summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmpatternedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmpatternedit.h')
-rw-r--r--kpovmodeler/pmpatternedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmpatternedit.h b/kpovmodeler/pmpatternedit.h
index 6826e13b..fea9f140 100644
--- a/kpovmodeler/pmpatternedit.h
+++ b/kpovmodeler/pmpatternedit.h
@@ -45,12 +45,13 @@ class TQPushButton;
class PMPatternEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMPatternEdit with parent and name
*/
- PMPatternEdit( TQWidget* parent, const char* name = 0 );
+ PMPatternEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -45,12 +45,13 @@ class TQPushButton;
public:
/**
- * Creates a PMPatternEdit with parent and name
+ * Creates a PMPatternEdit with tqparent and name
*/